@@ -1,4 +1,4 @@
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 PROTECTED_KEYS = frozenset((
     'sid',
@@ -8,12 +8,16 @@ PROTECTED_KEYS = frozenset((
 ))
 
 
-def clear_params(dict_params: Dict[str, Any]) -> Dict[str, Any]:
+def clear_params(
+    dict_params: Optional[Dict[str, Any]],
+) -> Dict[str, Any]:
     """Clear PHI parameters.
 
     :param dict_params: params
     :return: cleared params
     """
+    if dict_params is None:
+        dict_params = {}
     return {
         key: p_value for key, p_value in dict_params.items()
         if key not in PROTECTED_KEYS
