@@ -4,6 +4,7 @@ import json
 from typing import Dict, List, Union
 
 from ambra_sdk.models.base import FieldDescriptor
+from ambra_sdk.request_args import RequestArgs
 
 OnlyField = Union[str, Dict[str, List[str]], FieldDescriptor]
 
@@ -13,7 +14,7 @@ OnlyFields = Union[OnlyField, List[OnlyField]]
 class WithOnly:
     """With only fields mixin."""
 
-    request_data: Dict
+    request_args: RequestArgs
 
     def only_top_field(self, field: str):
         """Request only one top field.
@@ -21,13 +22,15 @@ class WithOnly:
         :param field: top field name
         :return: self object
         """
-        top_fields = self.request_data.get('fields._top')
+        request_data = self.request_args.data or {}
+        top_fields = request_data.get('fields._top')
         if top_fields:
             top_fields = json.loads(top_fields)
             top_fields.append(field)
         else:
             top_fields = [field]
-        self.request_data['fields._top'] = json.dumps(top_fields)
+        request_data['fields._top'] = json.dumps(top_fields)
+        self.request_args.data = request_data  # NOQA:WPS110
         return self
 
     def only_top_fields(self, fields: List[str]):
@@ -36,13 +39,15 @@ class WithOnly:
         :param fields: list of top fields
         :return: self object
         """
-        top_fields = self.request_data.get('fields._top')
+        request_data = self.request_args.data or {}
+        top_fields = request_data.get('fields._top')
         if top_fields:
             top_fields = json.loads(top_fields)
             top_fields.extend(fields)
         else:
             top_fields = fields
-        self.request_data['fields._top'] = json.dumps(top_fields)
+        request_data['fields._top'] = json.dumps(top_fields)
+        self.request_args.data = request_data  # NOQA:WPS110
         return self
 
     def only_struct_fields(self, fields: Dict[str, List[str]]):
@@ -52,18 +57,20 @@ class WithOnly:
                        Name of struct: list of fields
         :return: self object
         """
+        request_data = self.request_args.data or {}
         for struct_name, struct_fields in fields.items():
             struct_name = 'fields.{struct_name}'.format(
                 struct_name=struct_name,
             )
-            struct_fields_list = self.request_data.get(struct_name)
+            struct_fields_list = request_data.get(struct_name)
             if struct_fields_list:
                 struct_fields_list = json.loads(struct_fields_list)
                 struct_fields_list.extend(struct_fields)
             else:
                 struct_fields_list = struct_fields
             struct_fields_list = sorted(set(struct_fields_list))
-            self.request_data[struct_name] = json.dumps(struct_fields_list)
+            request_data[struct_name] = json.dumps(struct_fields_list)
+        self.request_args.data = request_data  # NOQA:WPS110
         return self
 
     def only(self, fields: OnlyFields):  # NOQA:WPS231
