@@ -1,7 +1,9 @@
 """Sorting."""
 
 from enum import Enum
-from typing import Dict, NamedTuple
+from typing import NamedTuple
+
+from ambra_sdk.request_args import RequestArgs
 
 
 class SortingOrder(Enum):
@@ -31,7 +33,7 @@ class Sorter(NamedTuple):
 class WithSorting:
     """With sorting mixin."""
 
-    request_data: Dict
+    request_args: RequestArgs
 
     def sort_by(self, sorter_obj: Sorter):
         """Sort by sorter.
@@ -39,7 +41,8 @@ class WithSorting:
         :param sorter_obj: sorter object
         :return: self object
         """
-        sort_by = self.request_data.get('sort_by')
+        request_data = self.request_args.data or {}
+        sort_by = request_data.get('sort_by')
         if sort_by is None:
             sort_by = str(sorter_obj)
         else:
@@ -47,5 +50,6 @@ class WithSorting:
                 sort_by=sort_by,
                 new_field=str(sorter_obj),
             )
-        self.request_data['sort_by'] = sort_by
+        request_data['sort_by'] = sort_by
+        self.request_args.data = request_data  # NOQA:WPS110
         return self
